@@ -62,6 +62,28 @@ def main():
             abs_dirpath = os.path.join(os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))), "toolshed", "c")
             compile_c_code(abs_dirpath) # function calls exit status code
     #------------------------------------------------------------------------------
+    # [ dist ] - distribute source files to PyPI (2)=register, sdist, wheel, win, all, help
+    #------------------------------------------------------------------------------
+    elif c.cmd == "dist":
+        if c.argc > 1:
+            from Naked.commands.dist import Dist
+            d = Dist()
+            if c.cmd2 == "register": # python setup.py register
+                d.run('register')
+            elif c.cmd2 == "sdist":  # python setup.py sdist upload
+                d.run('sdist')
+            elif c.cmd2 == "wheel":  # python setup.py bdist_wheel upload
+                d.run('wheel')
+            elif c.cmd2 == "win":    # python setup.py bdist_wininst upload
+                d.run('win')
+            elif c.cmd2 == "all":    # python setup.py sdist bdist_wheel bdist_wininst upload
+                d.run('all')
+            elif c.cmd2 == "help":   # help for command
+                from Naked.commands.dist import help as dist_help
+                dist_help()
+        else:
+            stderr("Please enter a secondary command", 1)
+    #------------------------------------------------------------------------------
     # [ locate ] - locate Naked project files (2)= main, settings, setup
     #------------------------------------------------------------------------------
     elif c.cmd == "locate":
@@ -91,12 +113,31 @@ def main():
             m = MakeController(None)
         m.run()
     #------------------------------------------------------------------------------
-    # [ test ] - Run tox tests on the project (2)= tox  (args)=tox py_version arg
+    # [ profile ] - run the profiler.py file in the Naked project
+    #------------------------------------------------------------------------------
+    elif c.cmd == "profile":
+        if c.cmd2 == "help":
+            from Naked.commands.profile import help as profile_help
+            profile_help()
+        else:
+            from Naked.commands.profile import Profiler
+            p = Profiler()
+            p.run()
+    #------------------------------------------------------------------------------
+    # [ test ] - Run unit tests on the project (2)= help,nose,pytest,tox,unittest (see help for args)
     #------------------------------------------------------------------------------
     elif c.cmd == "test":
         if c.cmd2 == "help":
                 from Naked.commands.test import help as tox_help
                 tox_help()
+        elif c.cmd2 == "nose":
+            from Naked.commands.test import NoseTester
+            n = NoseTester()
+            n.run()
+        elif c.cmd2 == "pytest":
+            from Naked.commands.test import PyTester
+            p = PyTester()
+            p.run()
         elif c.cmd2 == "tox":
             from Naked.commands.test import ToxTester
             if c.arg2: #user specified a python version to run with one of the tox version defs
@@ -104,6 +145,13 @@ def main():
             else:
                 t = ToxTester()
             t.run()
+        elif c.cmd2 == "unittest":
+            from Naked.commands.test import UnitTester
+            if c.arg2:
+                t = UnitTester(c.arg2)
+                t.run()
+            else:
+                stderr("Please include a unit test file path.  Use 'naked test help' for more information.", 1)
 
     #------------------------------------------------------------------------------------------
     # [ NAKED FRAMEWORK COMMANDS ]
